@@ -1,4 +1,4 @@
-/* Copyright 2014,2015,2018,2021,2023 IPB, Universite de Bordeaux, INRIA & CNRS
+/* Copyright 2014,2015,2018,2021,2023,2024 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -34,6 +34,7 @@
 /**   NAME       : test_scotch_dgraph_coarsen.c            **/
 /**                                                        **/
 /**   AUTHOR     : Francois PELLEGRINI                     **/
+/**                Clement BARTHELEMY                      **/
 /**                                                        **/
 /**   FUNCTION   : This module tests the operation of      **/
 /**                the SCOTCH_dgraphCoarsen() routine.     **/
@@ -43,7 +44,7 @@
 /**                # Version 6.1  : from : 16 jun 2021     **/
 /**                                 to   : 28 dec 2021     **/
 /**                # Version 7.0  : from : 03 jul 2023     **/
-/**                                 to   : 12 aug 2023     **/
+/**                                 to   : 04 jul 2024     **/
 /**                                                        **/
 /************************************************************/
 
@@ -52,18 +53,10 @@
 */
 
 #include <mpi.h>
-#include <stdio.h>
-#if (((defined __STDC_VERSION__) && (__STDC_VERSION__ >= 199901L)) || (defined HAVE_STDINT_H))
-#include <stdint.h>
-#endif /* (((defined __STDC_VERSION__) && (__STDC_VERSION__ >= 199901L)) || (defined HAVE_STDINT_H)) */
-#include <stdlib.h>
-#include <sys/time.h>
-#include <sys/types.h>
-#include <pthread.h>
-#include <unistd.h>
 
 #include "../libscotch/module.h"
 #include "../libscotch/common.h"
+
 #include "ptscotch.h"
 
 static File                 C_fileTab[1] = { /* File array */
@@ -91,7 +84,6 @@ char *              argv[])
   SCOTCH_Num          coarvertglbnbr;
   SCOTCH_Num          coarvertlocnbr;
   double              coarrat;
-  FILE *              file;
 #ifdef SCOTCH_PTHREAD
   int                 thrdreqlvl;
   int                 thrdprolvl;
