@@ -1,4 +1,4 @@
-/* Copyright 2015,2016,2018,2019 IPB, Universite de Bordeaux, INRIA & CNRS
+/* Copyright 2015,2016,2018,2019,2023 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -42,7 +42,7 @@
 /**   DATES      : # Version 6.0  : from : 02 may 2015     **/
 /**                                 to   : 22 feb 2018     **/
 /**                # Version 7.0  : from : 22 aug 2019     **/
-/**                                 to   : 12 sep 2019     **/
+/**                                 to   : 17 jan 2023     **/
 /**                                                        **/
 /**   NOTES      : # The code of the main routine derives  **/
 /**                  from that of archSubArchBuild().      **/
@@ -53,8 +53,8 @@
 **  The defines and includes.
 */
 
-#define ARCH_DECO2
-#define ARCH_BUILD2
+#define SCOTCH_ARCH_DECO2
+#define SCOTCH_ARCH_BUILD2
 
 #include "module.h"
 #include "common.h"
