@@ -42,7 +42,7 @@
 /**   DATES      : # Version 6.0  : from : 13 mar 2015     **/
 /**                                 to   : 15 may 2018     **/
 /**                # Version 7.0  : from : 13 sep 2019     **/
-/**                                 to   : 17 jan 2023     **/
+/**                                 to   : 13 aug 2024     **/
 /**                                                        **/
 /************************************************************/
 
@@ -475,7 +475,7 @@ const Anum * const          vnumtab)              /* Ordered list of remaining t
     treetab[orgtermnum].vertnum = orgtermnum;     /* Vertex number in original architecture                    */
   }
 
-  rootptr = archSubArchBuild2 (&matcdat, orgarchptr->class->matchMate, treetab, vnumnbr);
+  rootptr = archSubArchBuild2 (&matcdat, (Anum (*) (void *, ArchCoarsenMulti * restrict *)) orgarchptr->class->matchMate, treetab, vnumnbr);
 
   orgarchptr->class->matchExit (&matcdat);        /* Free matching structure */
 
