@@ -1,4 +1,4 @@
-/* Copyright 2004,2007,2008,2010,2012,2014,2018-2020 IPB, Universite de Bordeaux, INRIA & CNRS
+/* Copyright 2004,2007,2008,2010,2012,2014,2018-2020,2023 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -47,7 +47,7 @@
 /**                # Version 6.0  : from : 27 mar 2012     **/
 /**                                 to   : 20 aug 2020     **/
 /**                # Version 7.0  : from : 05 may 2019     **/
-/**                                 to   : 05 may 2019     **/
+/**                                 to   : 19 jan 2023     **/
 /**                                                        **/
 /************************************************************/
 
@@ -55,8 +55,7 @@
 **  The defines and includes.
 */
 
-#define HGRAPH
-#define HGRAPH_INDUCE
+#define SCOTCH_HGRAPH_INDUCE
 
 #include "module.h"
 #include "common.h"
