@@ -1,4 +1,4 @@
-/* Copyright 2004,2007,2010,2018,2021,2023 IPB, Universite de Bordeaux, INRIA & CNRS
+/* Copyright 2004,2007,2010,2018,2021,2023,2024 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -48,7 +48,7 @@
 /**                # Version 6.1  : from : 15 mar 2021     **/
 /**                                 to   : 15 mar 2021     **/
 /**                # Version 7.0  : from : 21 jan 2023     **/
-/**                                 to   : 21 jan 2023     **/
+/**                                 to   : 09 aug 2024     **/
 /**                                                        **/
 /************************************************************/
 
@@ -119,5 +119,5 @@ SCOTCH_Idx * const          geomidx), \
   double *            geomtab;
 
   SCOTCH_geomData (geomptr, dimnptr, &geomtab);
-  *geomidx = (geomtab - indxptr) + 1;             /* Add 1 since Fortran indices start at 1 */
+  *geomidx = (SCOTCH_Idx) (geomtab - indxptr) + 1; /* Add 1 since Fortran indices start at 1 */
 }
