@@ -1,4 +1,4 @@
-/* Copyright 2004,2007,2019,2020 IPB, Universite de Bordeaux, INRIA & CNRS
+/* Copyright 2004,2007,2019,2020,2023 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -45,7 +45,7 @@
 /**                # Version 6.0  : from : 23 jan 2020     **/
 /**                                 to   : 23 jan 2020     **/
 /**                # Version 7.0  : from : 12 sep 2019     **/
-/**                                 to   : 28 aug 2020     **/
+/**                                 to   : 20 jan 2023     **/
 /**                                                        **/
 /**   NOTES      : # The coarsening process is as follows. **/
 /**                  First, node collapsing is performed,  **/
@@ -60,7 +60,7 @@
 **  The defines and includes.
 */
 
-#define MESH_COARSEN
+#define SCOTCH_MESH_COARSEN
 
 #include "module.h"
 #include "common.h"
