@@ -1,4 +1,4 @@
-/* Copyright 2004,2007,2010,2018,2019,2021 IPB, Universite de Bordeaux, INRIA & CNRS
+/* Copyright 2004,2007,2010,2018,2019,2021,2023 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -52,7 +52,7 @@
 /**                # Version 6.0  : from : 27 apr 2018     **/
 /**                                 to   : 26 oct 2019     **/
 /**                # Version 7.0  : from : 02 mar 2018     **/
-/**                                 to   : 06 jul 2021     **/
+/**                                 to   : 20 jan 2023     **/
 /**                                                        **/
 /************************************************************/
 
@@ -77,8 +77,8 @@ extern unsigned int         stratmethtokentab[];
 **  The function prototypes.
 */
 
-#ifdef PARSER_YY
+#ifdef SCOTCH_PARSER_YY
 static void                 scotchyyerror       (const ParserLocation * const, void * const, const ParserEnv * const, const char * const);
-#endif /* PARSER_YY */
+#endif /* SCOTCH_PARSER_YY */
 
 Strat *                     stratParserParse    (const StratTab * const, const char * const);
