@@ -1,4 +1,4 @@
-/* Copyright 2004,2007,2008,2010-2012,2014,2018,2019,2021,2023 IPB, Universite de Bordeaux, INRIA & CNRS
+/* Copyright 2004,2007,2008,2010-2012,2014,2018,2019,2021,2023,2024 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -61,7 +61,7 @@
 /**                # Version 6.1  : from : 04 apr 2021     **/
 /**                                 to   : 28 aug 2021     **/
 /**                # Version 7.0  : from : 31 aug 2021     **/
-/**                                 to   : 21 jan 2023     **/
+/**                                 to   : 09 aug 2024     **/
 /**                                                        **/
 /************************************************************/
 
@@ -667,13 +667,14 @@ int * const                 codeval,             /* Pointer to the code value to
 char * const                string)              /* Pointer to the string to parse     */
 {
   int                 code;                      /* Code found                       */
-  int                 codelen;                   /* Code name length                 */
+  size_t              codelen;                   /* Code name length                 */
   char                argbuf[128];               /* Buffer for argument scanning     */
   int                 arglen;                    /* Length of the current argument   */
   char *              argbeg;                    /* Pointer to beginning of argument */
   char *              argend;                    /* Pointer to end of argument       */
   char *              argequ;                    /* Position of the '=' character    */
-  int                 i, j;
+  int                 i;
+  size_t              j;
 
   code    =
   codelen = 0;                                   /* No code recognized yet              */
